# -*- coding: utf-8 -*- 
"""
test de chargement et de manipulation de fichier pickle
de la base de mots-clef

"""
from os import path as osp
from os import unlink
import shutil

import autopath

from filtrage.db import *
from filtrage.guesser import train_guesser

KEYWORDS = ['noporn', 'porn']
DATA = osp.join(autopath.HERE, 'data')
BAYES_DB = osp.join(DATA,'db', 'guesser.bay')


def setup_module(module):
    """creation des bases bayesiennes (fichiers en .bay)
    définies par les mots-clef
    """
    print "setup"
    assert osp.isfile(BAYES_DB)
    shutil.copy(BAYES_DB, BAYES_DB + '.first')

def teardown_module(module):
    print "teardown"
    shutil.copy(BAYES_DB + '.first', BAYES_DB)

def rm_database():
    "suppression des fichiers de bases baysiennes"
    unlink(BAYES_DB)

def test_load_pickle_file():
    """creation des bases bayesiennes (fichiers en .bay)
    définies par les mots-clef
    """
    assert osp.isfile(BAYES_DB)
    d = load_pickle(BAYES_DB)
    assert d.keys() == KEYWORDS

def test_pickle():
    assert osp.isfile(BAYES_DB)
    d = load_pickle(BAYES_DB)
    assert not d['porn'].has_key('testkeyword')
    assert add_pickle('porn', ('testkeyword', 44), filename=BAYES_DB)
    d = load_pickle(BAYES_DB)
    assert d['porn']['testkeyword'] == 44

def test_del_to_pickle():
    assert osp.isfile(BAYES_DB)
    # ajout du mot-clef à enlever après
    assert add_pickle('porn', ('testkeyword', 44), filename=BAYES_DB)
    assert del_pickle('porn', 'testkeyword', filename=BAYES_DB)
    d = load_pickle(BAYES_DB)
    assert not d['porn'].has_key('testkeyword')


def test_add_to_pickle():
    empty_db = osp.join(DATA,'db', 'empty.db')
    shutil.copy(empty_db, empty_db + '.ori')

    pickle_db = osp.join(DATA,'db', 'pickle.db')
    shutil.copy(pickle_db, pickle_db + '.ori')

    assert osp.isfile(empty_db)

    p = PickleDB(filename=empty_db)
    p.add_keyword('porn')
    p.add_keyword('noporn')
    p.save()
    
    add_pickle('porn', ('toto', 10), filename=empty_db)
    add_pickle('porn', ('titi', 20), filename=empty_db)
    add_pickle('noporn', ('pine', 80), filename=empty_db)
    add_pickle('noporn', ('zob', 90), filename=empty_db)

    p = PickleDB(filename=empty_db)
    p2 = PickleDB(filename=pickle_db)
    p2.update_bayesdict(p)
    p2.save()

    d = load_pickle(pickle_db)
    assert d['noporn'].has_key('pine')
    d = load_pickle(pickle_db)
    assert d['noporn']['pine'] == 80

    shutil.copy(empty_db + '.ori', empty_db)
    shutil.copy(pickle_db + '.ori', pickle_db)
