# -*- coding: utf-8 -*- 
import autopath
import os.path as osp
import os

from filtrage.logparser import CSVStorage

# # exemple de fichier acces.log
# ACCES_LOG_FILE = """
# "2007.4.12 17:44:30","-","10.121.88.5","http://database.clamav.net/daily-3081.cdiff","","GET","687","0","","1","200","text/plain","",""
# "2007.4.12 17:44:30","-","10.121.88.5","http://database.clamav.net/daily-3082.cdiff","","GET","822","0","","1","200","text/plain","",""
# "2007.4.12 17:44:39","anne.baffy","172.16.88.20","http://www.google.com","","GET","218","0","","1","302","text/html","",""
# "2007.4.12 17:44:39","anne.baffy","172.16.88.20","http://www.google.fr","","GET","3934","0","","1","200","text/html","",""


DATA = osp.join(autopath.HERE, 'data')

def test_read_data():
    """lecture des données dans un fichier de types acces.log"""
    keywords = ['date','login','ip', 'url', 'method', 'chiffre1', 'chiffre2']
    c = CSVStorage(keywords=keywords, filename=osp.join(DATA, 'acces.log')) 
    c.load_data()
    expected = [{'url': 'http://database.clamav.net/daily-3081.cdiff', 'ip': '10.121.88.5', 'chiffre2': '687', 'date': '2007.4.12 17:44:30', 'login': '-', 'method': '', 'chiffre1': 'GET'}, {'url': 'http://database.clamav.net/daily-3082.cdiff', 'ip': '10.121.88.5', 'chiffre2': '822', 'date': '2007.4.12 17:44:30', 'login': '-', 'method': '', 'chiffre1': 'GET'}, {'url': 'http://www.google.com', 'ip': '172.16.88.20', 'chiffre2': '218', 'date': '2007.4.12 17:44:39', 'login': 'anne.baffy', 'method': '', 'chiffre1': 'GET'}, {'url': 'http://www.google.fr', 'ip': '172.16.88.20', 'chiffre2': '3934', 'date': '2007.4.12 17:44:39', 'login': 'anne.baffy', 'method': '', 'chiffre1': 'GET'}]
    assert c.get_data() == expected

def test_write_data():
    """ecriture des données récupérées"""
    keywords = ['date','login','ip', 'url', 'method', 'chiffre1', 'chiffre2']
    filename = osp.join(DATA, 'essai.txt')
    c = CSVStorage(keywords=keywords, filename=filename)
    data = [["2007.4.12 17:44:39","toto.titi","172.16.88.20","http://www.google.com","","GET","218","0","","1","302","text/html","",""]]
    c.set_data(data)
    c.write_data()
    assert os.path.isfile(filename)
    os.unlink(filename)

def test_filter():
    "filtre des données contenant des sites déjà interdits"
    keywords = ['date','login','ip', 'url', 'exception', 'method', 'chiffre1']
    c = CSVStorage(keywords=keywords, filename=osp.join(DATA, 'acces.log.filter')) 
    c.load_data()
    # il y a bien un site interdit dans les résultat
    res = [data['exception'] for data in c.data]
    assert '*EXCEPTION* Site interdit trouve.' in res
    # filtrage
    c.filter('exception', '*EXCEPTION*')
    res = [data['exception'] for data in c.data]
    assert '*EXCEPTION* Site interdit trouve.' not in res
    
